## 0.1.3 (2023-11-23)

### Fix

- add context for SopsyUnparsableOutpoutTypeError

## 0.1.2 (2023-11-22)

### Fix

- add license

## 0.1.1 (2023-11-22)

### Refactor

- make pyyaml optional

## 0.1.0 (2023-11-22)

### Feat

- release sopsy
